# WhoamiRequest

Identification token required by Whoami when logging in
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id_token** | **str** | id_token | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


